@@ -14,7 +14,7 @@ use constant default_suffix => '.toml';
 use constant default_encoding => ':utf8';
 
 # ABSTRACT
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 sub accept_suffix
@@ -128,7 +128,7 @@ FFI::Build::File::Cargo
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -142,17 +142,26 @@ Add this to your C<ffi/Cargo.toml> file to get dynamic libraries:
  [lib]
  crate-type = ["cdylib"]
 
-Your library goes in C<lib/MyLib.pm>:
+Add Rust code to C<ffi/src/lib.rs> that you want to call from Perl:
+
+ #![crate_type = "cdylib"]
+ 
+ #[no_mangle]
+ pub extern "C" fn add(a: i32, b: i32) -> i32 {
+     a + b
+ }
+
+Your Perl bindings go in a C<.pm> file like C<lib/MyLib.pm>:
 
  package MyLib;
  
- use FFI::Platypus 1.00;
+ use FFI::Platypus 2.00;
  
- my $ffi = FFI::Platypus->new( api => 1, lang => 'Rust' );
+ my $ffi = FFI::Platypus->new( api => 2, lang => 'Rust' );
  # configure platypus to use the bundled Rust code
  $ffi->bundle;
  
- ...
+ $ffi->attach( 'add' => ['i32','i32'] => 'i32' );
 
 Your C<Makefile.PL>:
 
@@ -183,6 +192,17 @@ Your C<Makefile.PL>:
 or alternatively, your C<dist.ini>:
 
  [FFI::Build]
+ lang = Rust
+ build = Cargo
+
+Write a test:
+
+ use Test2::V0;
+ use MyLib;
+ 
+ is MyLib::add(1,2), 3;
+ 
+ done_testing;
 
 =head1 DESCRIPTION
 
