@@ -8,7 +8,7 @@ use File::Spec;
 use Env qw( @PATH );
 
 # ABSTRACT: Documentation and tools for using Platypus with the Rust programming language
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 sub native_type_map
@@ -47,7 +47,7 @@ FFI::Platypus::Lang::Rust - Documentation and tools for using Platypus with the
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -86,11 +86,6 @@ reduce cognitive load and concentrate on Rust and forget about C types.
 This document also documents issues and caveats that I have discovered
 in my attempts to work with Rust and FFI.
 
-This module is somewhat experimental.  It is also available for adoption
-for anyone either sufficiently knowledgeable about Rust or eager enough
-to learn enough about Rust.  If you are interested, please send me a
-pull request or two on the project's GitHub.
-
 Note that in addition to using pre-compiled Rust libraries, you can
 bundle Rust code with your Perl distribution using L<FFI::Build> and
 L<FFI::Build::File::Cargo>.
@@ -901,7 +896,7 @@ have to care!
 
 =head3 Execute
 
- $ perl panic.pl                     
+ $ perl panic.pl
  thread '<unnamed>' panicked at 'oops!', panic.rs:7:9
  note: run with `RUST_BACKTRACE=1` environment variable to display a backtrace
  -1
